package com.zhentao.information.cache;

import io.netty.channel.group.ChannelGroup;
import io.netty.channel.group.DefaultChannelGroup;
import io.netty.util.concurrent.GlobalEventExecutor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * 群聊Channel缓存管理类
 * 用于管理群聊ChannelGroup
 */
@Slf4j
@Component
public class GroupChannelCache {
    
    /**
     * 群ID和ChannelGroup的映射关系
     * key: 群ID
     * value: ChannelGroup
     */
    private static final Map<Long, ChannelGroup> GROUP_CHANNEL_MAP = new ConcurrentHashMap<>();

    /**
     * 添加群聊ChannelGroup
     * @param groupId 群ID
     * @return ChannelGroup
     */
    public ChannelGroup addGroup(Long groupId) {
        ChannelGroup channelGroup = new DefaultChannelGroup(GlobalEventExecutor.INSTANCE);
        GROUP_CHANNEL_MAP.put(groupId, channelGroup);
        log.info("群 {} 的ChannelGroup已创建", groupId);
        return channelGroup;
    }

    /**
     * 获取群聊ChannelGroup
     * @param groupId 群ID
     * @return ChannelGroup
     */
    public ChannelGroup getGroup(Long groupId) {
        return GROUP_CHANNEL_MAP.get(groupId);
    }

    /**
     * 移除群聊ChannelGroup
     * @param groupId 群ID
     */
    public void removeGroup(Long groupId) {
        GROUP_CHANNEL_MAP.remove(groupId);
        log.info("群 {} 的ChannelGroup已移除", groupId);
    }

    /**
     * 获取所有群聊ChannelGroup
     * @return 群聊ChannelGroup映射Map
     */
    public Map<Long, ChannelGroup> getAllGroups() {
        return GROUP_CHANNEL_MAP;
    }

    /**
     * 判断群聊是否存在
     * @param groupId 群ID
     * @return 是否存在
     */
    public boolean exists(Long groupId) {
        return GROUP_CHANNEL_MAP.containsKey(groupId);
    }
} 